# {%= name %} {%= badge("fury") %}

> {%= description %}

## Install
{%= include("install") %}

## Run tests

```bash
npm test
```

## Usage

```js
var files = require('{%= name %}');
console.log(files('templates/*.txt'));
```
Returns an object that looks something like:

```js
{ a: { content: 'AAA', path: 'templates/a.txt' },
  b: { content: 'BBB', path: 'templates/b.txt' },
  c: { content: 'CCC', path: 'templates/c.txt' }}
```

### options.cwd

Define the current working directory

```js
files('*.txt', {cwd: 'templates'});
```

### options.name

Rename the key of each file object:

```js
var templates = files('templates/*.txt', {
  name: function (filepath) {
    return path.basename(filepath);
  }
});
```
Returns something like:

```js
{ 'a.txt': { content: 'AAA', path: 'templates/a.txt' },
  'b.txt': { content: 'BBB', path: 'templates/b.txt' },
  'c.txt': { content: 'CCC', path: 'templates/c.txt' }}
```


### options.read

> Pass a custom `read` function to change the object returned for each file.


The default function reads files and returns a string, but you can do anything
you want with the function, like `require` files:

```js
var helpers = files('helpers/*.js', {
  read: function (fp) {
    return require(path.resolve(fp));
  }
});
//=> { a: [Function: foo], b: [Function: bar], c: [Function: baz] }
```


## Author
{%= include("author") %}

## License
{%= copyright() %}
{%= license() %}

***

{%= include("footer") %}

[globby]: https://github.com/sindresorhus/globby