# map-files [![NPM version](https://badge.fury.io/js/map-files.svg)](http://badge.fury.io/js/map-files)

> Return an object for a glob of files. Pass a `rename` function for the keys, or a `parse` function for the content, allowing it to be used for readable or require-able files.

## Install
### Install with [npm](npmjs.org):

```bash
npm i map-files --save-dev
```

## Run tests

```bash
npm test
```

## Usage

```js
var files = require('map-files');
console.log(files('templates/*.txt'));
```
Returns an object that looks something like:

```js
{ a: { content: 'AAA', path: 'templates/a.txt' },
  b: { content: 'BBB', path: 'templates/b.txt' },
  c: { content: 'CCC', path: 'templates/c.txt' }}
```

### options.cwd

Define the current working directory

```js
files('*.txt', {cwd: 'templates'});
```

### options.name

Rename the key of each file object:

```js
var templates = files('templates/*.txt', {
  name: function (filepath) {
    return path.basename(filepath);
  }
});
```
Returns something like:

```js
{ 'a.txt': { content: 'AAA', path: 'templates/a.txt' },
  'b.txt': { content: 'BBB', path: 'templates/b.txt' },
  'c.txt': { content: 'CCC', path: 'templates/c.txt' }}
```


### options.read

> Pass a custom `read` function to change the object returned for each file.


The default function reads files and returns a string, but you can do anything
you want with the function, like `require` files:

```js
var helpers = files('helpers/*.js', {
  read: function (fp) {
    return require(path.resolve(fp));
  }
});
//=> { a: [Function: foo], b: [Function: bar], c: [Function: baz] }
```


## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2014 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb](https://github.com/assemble/verb) on December 05, 2014._

[globby]: https://github.com/sindresorhus/globby