# arr-map [![NPM version](https://badge.fury.io/js/arr-map.svg)](http://badge.fury.io/js/arr-map)

> Faster, node.js focused alternative to JavaScript's native array map.

JavaScript's native `Array.map()` is slow, and other popular array map libraries are focused on browser compatibility. This implementation is focused on node.js usage keeping it light and fast.

## Install with [npm](npmjs.org)

```bash
npm i arr-map --save
```

## Usage

```js
var map = require('arr-map');

map(['a', 'b', 'c'], function (ele) {
  return ele + ele;
});
//=> ['aa', 'bb', 'cc']

map(['a', 'b', 'c'], function (ele, i) {
  return i + ele;
});
//=> ['0a', '1b', '2c']
```

## Run tests

Install dev dependencies:

```bash
node i -d && mocha
```

## Run benchmarks

Install dev dependencies:

```bash
node i -d && npm benchmark
```

[Benchmarks](./benchmark) from January 30, 2015

```bash
#1: long.js
  arr-map.js x 19,418 ops/sec ±0.62% (98 runs sampled)
  native.js x 8,312 ops/sec ±0.80% (98 runs sampled)

#2: med.js
  arr-map.js x 402,100 ops/sec ±0.72% (97 runs sampled)
  native.js x 156,813 ops/sec ±1.74% (91 runs sampled)

#3: short.js
  arr-map.js x 1,445,561 ops/sec ±0.67% (97 runs sampled)
  native.js x 480,518 ops/sec ±1.64% (86 runs sampled)
```


## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/arr-map/issues)

## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2015 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb](https://github.com/assemble/verb) on January 30, 2015._
